pub struct Channel {
pub id: i64,
pub registered_by: i64,
pub link: String,
pub name: String,
}Expand description
The Channel structure is used for identifying both channels and (super)groups, since they have the very same attributes.
Fields
id: i64Channel unique ID, Telegram generated.
registered_by: i64User unique ID, the user that registered the channel to the bot. Almost always the channel creator.
link: StringThe invitation link for the channel. Can be the user-decided one or the private-link Telegram generated.
name: StringChannel name