pub struct Contest {
pub id: i64,
pub name: String,
pub prize: String,
pub end: DateTime<Utc>,
pub started_at: Option<DateTime<Utc>>,
pub stopped: bool,
pub chan: i64,
}Expand description
A referral based strategy contest
Fields
id: i64Contest unique ID, locally generated
name: StringContest name, unique and locally generated
prize: StringThe prize the owner of the chan wants to give to the contest’s winner
end: DateTime<Utc>Contest end date and time. Invitations received after the end date won’t generate an increase in the ranking.
started_at: Option<DateTime<Utc>>Whenever the contest’s owner decided to start the Contest
stopped: boolTrue if the user decided to stop this contest.
chan: i64The channel ID for this contest