pub struct Rank {
pub rank: i64,
pub invites: i64,
pub user: User,
}Expand description
Rank is like a row in a ranking table.
Fields
rank: i64The position in the chart
invites: i64Number of invitations sent by this user
user: UserThe user that is in rank position because it sent invites invitations